%define with_python3 1
%define with_gtk_doc 1
%define with_btrfs 1
%define with_crypto 1
%define with_dm 1
%define with_loop 1
%define with_lvm 1
%define with_lvm_dbus 1
%define with_mdraid 1
%define with_mpath 1
%define with_swap 1
%define with_part 1
%define with_fs 1
%define with_nvdimm 1
%define with_gi 1
%define with_escrow 1
%define with_tools 1
%define with_nvme 1

# btrfs is not available on RHEL > 7
%if 0%{?rhel} > 7 || %{with_btrfs} == 0
%define with_btrfs 0
%define btrfs_copts --without-btrfs
%endif

%if %{with_btrfs} != 1
%define btrfs_copts --without-btrfs
%endif
%if %{with_crypto} != 1
%define crypto_copts --without-crypto
%else
%if %{with_escrow} != 1
%define crypto_copts --without-escrow
%endif
%endif
%if %{with_dm} != 1
%define dm_copts --without-dm
%else
%endif
%if %{with_loop} != 1
%define loop_copts --without-loop
%endif
%if %{with_lvm} != 1
%define lvm_copts --without-lvm
%endif
%if %{with_lvm_dbus} != 1
%define lvm_dbus_copts --without-lvm_dbus
%endif
%if %{with_mdraid} != 1
%define mdraid_copts --without-mdraid
%endif
%if %{with_mpath} != 1
%define mpath_copts --without-mpath
%endif
%if %{with_swap} != 1
%define swap_copts --without-swap
%endif
%if %{with_part} != 1
%define part_copts --without-part
%endif
%if %{with_fs} != 1
%define fs_copts --without-fs
%endif
%if %{with_nvdimm} != 1
%define nvdimm_copts --without-nvdimm
%endif
%if %{with_tools} != 1
%define tools_copts --without-tools
%endif
%if %{with_gi} != 1
%define gi_copts --disable-introspection
%endif
%if %{with_nvme} != 1
%define nvme_copts --without-nvme
%endif

%define configure_opts %{?python3_copts} %{?lvm_dbus_copts} %{?btrfs_copts} %{?crypto_copts} %{?dm_copts} %{?loop_copts} %{?lvm_copts} %{?lvm_dbus_copts} %{?mdraid_copts} %{?mpath_copts} %{?swap_copts} %{?part_copts} %{?fs_copts} %{?nvdimm_copts} %{?tools_copts} %{?gi_copts} %{?nvme_copts}

Name:        libblockdev
Version:     3.0
Release:     1.20230626120007099679.pr904.947.g6e10c72c%{?dist}
Summary:     A library for low-level manipulation with block devices
License:     LGPL-2.1-or-later
URL:         https://github.com/storaged-project/libblockdev
Source0:     libblockdev-3.0.tar.gz

BuildRequires: glib2-devel
%if %{with_gi}
BuildRequires: gobject-introspection-devel
%endif
%if %{with_python3}
BuildRequires: python3-devel
%endif
%if %{with_gtk_doc}
BuildRequires: gtk-doc
%endif
BuildRequires: glib2-doc
BuildRequires: autoconf-archive

# obsolete removed subpackages to allow upgrades
Obsoletes: libblockdev-kbd
Obsoletes: libblockdev-kbd-devel

Requires: %{name}-utils%{?_isa} = %{version}-%{release}

%description
The libblockdev is a C library with GObject introspection support that can be
used for doing low-level operations with block devices like setting up LVM,
BTRFS, LUKS or MD RAID. The library uses plugins (LVM, BTRFS,...) and serves as
a thin wrapper around its plugins' functionality. All the plugins, however, can
be used as standalone libraries. One of the core principles of libblockdev is
that it is stateless from the storage configuration's perspective (e.g. it has
no information about VGs when creating an LV).

%package devel
Summary:     Development files for libblockdev
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description devel
This package contains header files and pkg-config files needed for development
with the libblockdev library.

%if %{with_python3}
%package -n python3-blockdev
Summary:     Python3 gobject-introspection bindings for libblockdev
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: python3-gobject-base
Requires: python3-bytesize
%{?python_provide:%python_provide python3-blockdev}

%description -n python3-blockdev
This package contains enhancements to the gobject-introspection bindings for
libblockdev in Python3.
%endif

%package utils
BuildRequires: kmod-devel
Summary:     A library with utility functions for the libblockdev library

%description utils
The libblockdev-utils is a library providing utility functions used by the
libblockdev library and its plugins.

%package utils-devel
Summary:     Development files for libblockdev-utils
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description utils-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-utils library.


%if %{with_btrfs}
%package btrfs
BuildRequires: libbytesize-devel
Summary:     The BTRFS plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: btrfs-progs

%description btrfs
The libblockdev library plugin (and in the same time a standalone library)
providing the BTRFS-related functionality.

%package btrfs-devel
Summary:     Development files for the libblockdev-btrfs plugin/library
Requires: %{name}-btrfs%{?_isa} = %{version}-%{release}
Requires: glib2-devel
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}

%description btrfs-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-btrfs plugin/library.
%endif


%if %{with_crypto}
%package crypto
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
BuildRequires: cryptsetup-devel >= 2.3.0
BuildRequires: libblkid-devel
BuildRequires: keyutils-libs-devel

%if %{with_escrow}
BuildRequires: volume_key-devel >= 0.3.9-7
BuildRequires: nss-devel
%endif

Summary:     The crypto plugin for the libblockdev library

%description crypto
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to encrypted devices (LUKS).

%package crypto-devel
Summary:     Development files for the libblockdev-crypto plugin/library
Requires: %{name}-crypto%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description crypto-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-crypto plugin/library.
%endif


%if %{with_dm}
%package dm
BuildRequires: device-mapper-devel
BuildRequires: systemd-devel
Summary:     The Device Mapper plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: device-mapper

%description dm
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to Device Mapper.

%package dm-devel
Summary:     Development files for the libblockdev-dm plugin/library
Requires: %{name}-dm%{?_isa} = %{version}-%{release}
Requires: glib2-devel
Requires: device-mapper-devel
Requires: systemd-devel
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}

%description dm-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-dm plugin/library.
%endif


%if %{with_fs}
%package fs
BuildRequires: libblkid-devel
BuildRequires: libmount-devel
BuildRequires: libuuid-devel
BuildRequires: e2fsprogs-devel
Summary:     The FS plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}

%description fs
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to operations with file systems.

%package fs-devel
Summary:     Development files for the libblockdev-fs plugin/library
Requires: %{name}-fs%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description fs-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-fs plugin/library.
%endif


%if %{with_loop}
%package loop
Summary:     The loop plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}

%description loop
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to loop devices.

%package loop-devel
Summary:     Development files for the libblockdev-loop plugin/library
Requires: %{name}-loop%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description loop-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-loop plugin/library.
%endif


%if %{with_lvm}
%package lvm
BuildRequires: device-mapper-devel
Summary:     The LVM plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: lvm2

%description lvm
The libblockdev library plugin (and in the same time a standalone library)
providing the LVM-related functionality.

%package lvm-devel
Summary:     Development files for the libblockdev-lvm plugin/library
Requires: %{name}-lvm%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description lvm-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-lvm plugin/library.
%endif

%if %{with_lvm_dbus}
%package lvm-dbus
BuildRequires: device-mapper-devel
Summary:     The LVM plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: lvm2-dbusd >= 2.02.156

%description lvm-dbus
The libblockdev library plugin (and in the same time a standalone library)
providing the LVM-related functionality utilizing the LVM DBus API.

%package lvm-dbus-devel
Summary:     Development files for the libblockdev-lvm-dbus plugin/library
Requires: %{name}-lvm-dbus%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description lvm-dbus-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-lvm-dbus plugin/library.
%endif


%if %{with_mdraid}
%package mdraid
BuildRequires: libbytesize-devel
Summary:     The MD RAID plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: mdadm

%description mdraid
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to MD RAID.

%package mdraid-devel
Summary:     Development files for the libblockdev-mdraid plugin/library
Requires: %{name}-mdraid%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description mdraid-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-mdraid plugin/library.
%endif


%if %{with_mpath}
%package mpath
BuildRequires: device-mapper-devel
Summary:     The multipath plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: device-mapper-multipath

%description mpath
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to multipath devices.

%package mpath-devel
Summary:     Development files for the libblockdev-mpath plugin/library
Requires: %{name}-mpath%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description mpath-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-mpath plugin/library.
%endif

%if %{with_nvdimm}
%package nvdimm
BuildRequires: ndctl-devel
BuildRequires: libuuid-devel
Summary:     The NVDIMM plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: ndctl

%description nvdimm
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to operations with NVDIMM devices.

%package nvdimm-devel
Summary:     Development files for the libblockdev-nvdimm plugin/library
Requires: %{name}-nvdimm%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description nvdimm-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-nvdimm plugin/library.
%endif


%if %{with_nvme}
%package nvme
BuildRequires: libnvme-devel
BuildRequires: libuuid-devel
Summary:     The NVMe plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}

%description nvme
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to operations with NVMe devices.

%package nvme-devel
Summary:     Development files for the libblockdev-nvme plugin/library
Requires: %{name}-nvme%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description nvme-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-nvme plugin/library.
%endif


%if %{with_part}
%package part
BuildRequires: libfdisk-devel
Summary:     The partitioning plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: util-linux

%description part
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to partitioning.

%package part-devel
Summary:     Development files for the libblockdev-part plugin/library
Requires: %{name}-part%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description part-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-part plugin/library.
%endif


%if %{with_swap}
%package swap
BuildRequires: libblkid-devel
Summary:     The swap plugin for the libblockdev library
Requires: %{name}-utils%{?_isa} = %{version}-%{release}
Requires: util-linux

%description swap
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to swap devices.

%package swap-devel
Summary:     Development files for the libblockdev-swap plugin/library
Requires: %{name}-swap%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description swap-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-swap plugin/library.
%endif

%if %{with_tools}
%package tools
Summary:    Various nice tools based on libblockdev
Requires:   %{name} = %{version}-%{release}
Requires:   %{name}-lvm = %{version}-%{release}
BuildRequires: libbytesize-devel
BuildRequires: parted-devel
%if %{with_lvm_dbus} == 1
Recommends: %{name}-lvm-dbus
%endif

%description tools
Various nice storage-related tools based on libblockdev.

%endif

%ifarch s390 s390x
%package s390
Summary:    The s390 plugin for the libblockdev library
Requires: s390utils

%description s390
The libblockdev library plugin (and in the same time a standalone library)
providing the functionality related to s390 devices.

%package s390-devel
Summary:     Development files for the libblockdev-s390 plugin/library
Requires: %{name}-s390%{?_isa} = %{version}-%{release}
Requires: %{name}-utils-devel%{?_isa} = %{version}-%{release}
Requires: glib2-devel

%description s390-devel
This package contains header files and pkg-config files needed for development
with the libblockdev-s390 plugin/library.
%endif

%package plugins-all
Summary:     Meta-package that pulls all the libblockdev plugins as dependencies
Requires: %{name}%{?_isa} = %{version}-%{release}

%if %{with_btrfs}
Requires: %{name}-btrfs%{?_isa} = %{version}-%{release}
%endif

%if %{with_crypto}
Requires: %{name}-crypto%{?_isa} = %{version}-%{release}
%endif

%if %{with_dm}
Requires: %{name}-dm%{?_isa} = %{version}-%{release}
%endif

%if %{with_fs}
Requires: %{name}-fs%{?_isa} = %{version}-%{release}
%endif

%if %{with_loop}
Requires: %{name}-loop%{?_isa} = %{version}-%{release}
%endif

%if %{with_lvm}
Requires: %{name}-lvm%{?_isa} = %{version}-%{release}
%endif

%if %{with_mdraid}
Requires: %{name}-mdraid%{?_isa} = %{version}-%{release}
%endif

%if %{with_mpath}
Requires: %{name}-mpath%{?_isa} = %{version}-%{release}
%endif

%if %{with_nvdimm}
Requires: %{name}-nvdimm%{?_isa} = %{version}-%{release}
%endif

%if %{with_nvme}
Requires: %{name}-nvme%{?_isa} = %{version}-%{release}
%endif

%if %{with_part}
Requires: %{name}-part%{?_isa} = %{version}-%{release}
%endif

%if %{with_swap}
Requires: %{name}-swap%{?_isa} = %{version}-%{release}
%endif

%ifarch s390 s390x
Requires: %{name}-s390%{?_isa} = %{version}-%{release}
%endif

%description plugins-all
A meta-package that pulls all the libblockdev plugins as dependencies.


%prep
%setup -q -n libblockdev-3.0

%build
autoreconf -ivf
%configure %{?configure_opts}
%{__make} %{?_smp_mflags}

%install
%{make_install}
find %{buildroot} -type f -name "*.la" | xargs %{__rm}


%ldconfig_scriptlets
%ldconfig_scriptlets utils

%if %{with_btrfs}
%ldconfig_scriptlets btrfs
%endif

%if %{with_crypto}
%ldconfig_scriptlets crypto
%endif

%if %{with_dm}
%ldconfig_scriptlets dm
%endif

%if %{with_fs}
%ldconfig_scriptlets fs
%endif

%if %{with_loop}
%ldconfig_scriptlets loop
%endif

%if %{with_lvm}
%ldconfig_scriptlets lvm
%endif

%if %{with_lvm_dbus}
%ldconfig_scriptlets lvm-dbus
%endif

%if %{with_mdraid}
%ldconfig_scriptlets mdraid
%endif

%if %{with_mpath}
%ldconfig_scriptlets mpath
%endif

%if %{with_nvdimm}
%ldconfig_scriptlets nvdimm
%endif

%if %{with_nvme}
%ldconfig_scriptlets nvme
%endif

%if %{with_part}
%ldconfig_scriptlets part
%endif

%if %{with_swap}
%ldconfig_scriptlets swap
%endif

%ifarch s390 s390x
%ldconfig_scriptlets s390
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%{_libdir}/libblockdev.so.*
%if %{with_gi}
%{_libdir}/girepository*/BlockDev*.typelib
%endif
%dir %{_sysconfdir}/libblockdev
%dir %{_sysconfdir}/libblockdev/conf.d
%config %{_sysconfdir}/libblockdev/conf.d/00-default.cfg

%files devel
%doc features.rst specs.rst
%{_libdir}/libblockdev.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/blockdev.h
%{_includedir}/blockdev/plugins.h
%{_libdir}/pkgconfig/blockdev.pc
%if %{with_gtk_doc}
%{_datadir}/gtk-doc/html/libblockdev
%endif
%if %{with_gi}
%{_datadir}/gir*/BlockDev*.gir
%endif

%if %{with_python3}
%files -n python3-blockdev
%{python3_sitearch}/gi/overrides/BlockDev*
%{python3_sitearch}/gi/overrides/__pycache__/BlockDev*
%endif

%files utils
%{_libdir}/libbd_utils.so.*

%files utils-devel
%{_libdir}/libbd_utils.so
%{_libdir}/pkgconfig/blockdev-utils.pc
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/utils.h
%{_includedir}/blockdev/sizes.h
%{_includedir}/blockdev/exec.h
%{_includedir}/blockdev/extra_arg.h
%{_includedir}/blockdev/dev_utils.h
%{_includedir}/blockdev/module.h
%{_includedir}/blockdev/dbus.h
%{_includedir}/blockdev/logging.h


%if %{with_btrfs}
%files btrfs
%{_libdir}/libbd_btrfs.so.*

%files btrfs-devel
%{_libdir}/libbd_btrfs.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/btrfs.h
%endif


%if %{with_crypto}
%files crypto
%{_libdir}/libbd_crypto.so.*

%files crypto-devel
%{_libdir}/libbd_crypto.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/crypto.h
%endif


%if %{with_dm}
%files dm
%{_libdir}/libbd_dm.so.*

%files dm-devel
%{_libdir}/libbd_dm.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/dm.h
%endif


%if %{with_fs}
%files fs
%{_libdir}/libbd_fs.so.*

%files fs-devel
%{_libdir}/libbd_fs.so
%dir %{_includedir}/blockdev
%dir %{_includedir}/blockdev/fs
%{_includedir}/blockdev/fs.h
%{_includedir}/blockdev/fs/*.h
%endif


%if %{with_loop}
%files loop
%{_libdir}/libbd_loop.so.*

%files loop-devel
%{_libdir}/libbd_loop.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/loop.h
%endif


%if %{with_lvm}
%files lvm
%{_libdir}/libbd_lvm.so.*

%files lvm-devel
%{_libdir}/libbd_lvm.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/lvm.h
%endif


%if %{with_lvm_dbus}
%files lvm-dbus
%{_libdir}/libbd_lvm-dbus.so.*
%config %{_sysconfdir}/libblockdev/conf.d/10-lvm-dbus.cfg

%files lvm-dbus-devel
%{_libdir}/libbd_lvm-dbus.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/lvm.h
%endif


%if %{with_mdraid}
%files mdraid
%{_libdir}/libbd_mdraid.so.*

%files mdraid-devel
%{_libdir}/libbd_mdraid.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/mdraid.h
%endif


%if %{with_mpath}
%files mpath
%{_libdir}/libbd_mpath.so.*

%files mpath-devel
%{_libdir}/libbd_mpath.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/mpath.h
%endif


%if %{with_nvdimm}
%files nvdimm
%{_libdir}/libbd_nvdimm.so.*

%files nvdimm-devel
%{_libdir}/libbd_nvdimm.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/nvdimm.h
%endif


%if %{with_nvme}
%files nvme
%{_libdir}/libbd_nvme.so.*

%files nvme-devel
%{_libdir}/libbd_nvme.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/nvme.h
%endif


%if %{with_part}
%files part
%{_libdir}/libbd_part.so.*

%files part-devel
%{_libdir}/libbd_part.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/part.h
%endif


%if %{with_swap}
%files swap
%{_libdir}/libbd_swap.so.*

%files swap-devel
%{_libdir}/libbd_swap.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/swap.h
%endif


%if %{with_tools}
%files tools
%{_bindir}/lvm-cache-stats
%{_bindir}/vfat-resize
%endif

%ifarch s390 s390x
%files s390
%{_libdir}/libbd_s390.so.*

%files s390-devel
%{_libdir}/libbd_s390.so
%dir %{_includedir}/blockdev
%{_includedir}/blockdev/s390.h
%endif

%files plugins-all

%changelog
* Mon Jun 26 2023 Packit <hello@packit.dev> - 3.0-1.20230626120007099679.pr904.947.g6e10c72c
- Add part plugin to the plugin config files (Vojtech Trefny)
- Bump version to 3.0 (Vojtech Trefny)
- Sync NEWS.rst with 2.x branch (Vojtech Trefny)
- fs: Rename BDFs* enums to BDFS* (Vojtech Trefny)
- Make sure the API files are up-to-date (Vojtech Trefny)
- Replace C++ style comments with C style (Vojtech Trefny)
- docs: Document mdraid plugin 3.0 API changes (Tomas Bzatek)
- tests: Adapt mdraid tests to recent bitmap API changes (Tomas Bzatek)
- fs: Allow specifying extra options to all check/repair functions (Vojtech Trefny)
- docs: Change NVMe plugin description to be consistent with other plugins (Vojtech Trefny)
- Misc code style cleanup (Vojtech Trefny)
- modules: Fix checking for linux version (Vojtech Trefny)
- mdraid: Make bitmap argument of bd_md_create() to accept arbitrary string (Tomas Bzatek)
- plugins: Allow passing NULL to bd_plugin_spec_copy/free (Vojtech Trefny)
- dist: SPEC cleanup (Vojtech Trefny)
- tests: Add a test case for crypto keyslot context (Vojtech Trefny)
- crypto: Make algorithm non-optional for integrity format/open (Vojtech Trefny)
- docs: Update crypto plugin description (Vojtech Trefny)
- crypto: Unify all sector size variables to guint32 (Vojtech Trefny)
- crypto: Add example of context usage to the bd_crypto_luks_open docstring (Vojtech Trefny)
- docs: Document crypto plugin 3.0 API changes (Vojtech Trefny)
- crypto: Report error when unsupported context is used (Vojtech Trefny)
- crypto: Add a new context type "volume key" (Vojtech Trefny)
- crypto: Use the keyslot context for TrueCrypt/BITLK/FVAULT2 too (Vojtech Trefny)
- crypto: Add a new context type "keyring" (Vojtech Trefny)
- crypto: Change return type of bd_crypto_luks_status to const (Vojtech Trefny)
- crypto: Remove some obsolete ifdefs (Vojtech Trefny)
- crypto: Remove bd_crypto_tc_open_full (Vojtech Trefny)
- crypto: Remove the separate function to get LUKS metadata size (Vojtech Trefny)
- tests: Remove checks for LUKS2 support from crypto tests (Vojtech Trefny)
- crypto: Remove the LUKS2 technology (Vojtech Trefny)
- crypto: Plugin API rework (Vojtech Trefny)
- crypto: Allow passing NULL for error in bd_crypto_luks_remove_key (Vojtech Trefny)
- Do not show functions in default repr for python objects (Vojtech Trefny)
- s390: Do not try to close an unopened stream (Vojtech Trefny)
- misc: Update Vagrantfile (Vojtech Trefny)
- tests: Skip test_ext4_check on rawhide (Vojtech Trefny)
- crypto: Fix docstring for BDCryptoLUKSInfo (Vojtech Trefny)
- crypto: Add support for getting information about BITLK devices (Vojtech Trefny)
- tests: Skip crypto tests with argon2 in FIPS mode (Vojtech Trefny)
- tests: Fix test names in crypto_test (Vojtech Trefny)
- tests: Use longer passphrase for LUKS in dm_test (Vojtech Trefny)
- tests: Remove old and invalid rules for skipping tests (Vojtech Trefny)
- tests: Skip NVMe tests on CentOS/RHEL 8 (Vojtech Trefny)
- mount: Initialize libmount debugging (Tomas Bzatek)
- fs: Remove UUID option from bd_fs_nilfs2_mkfs_options (Vojtech Trefny)
- fs: Add support for setting and checking UUID/volume ID for VFAT (Vojtech Trefny)
- fs: Add support for setting and checking UUID/volume ID for exFAT (Vojtech Trefny)
- swap: Add a function to set UUID for an existing swap device (Vojtech Trefny)
- swap: Allow specifying custom UUID for mkswap (Vojtech Trefny)
- fs/xfs: Use xfs_spaceman instead of xfs_db for mounted filesystems (Marius Vollmer)
- nvme: Drop the discovery functionality (Tomas Bzatek)
- nvme: Fix 128-bit int conversion (Tomas Bzatek)
- nvme: Add support for 'keyring' and 'tls_key' fabrics attributes (Tomas Bzatek)
- nvme: Add support for ENVME_CONNECT_CONNREFUSED (Tomas Bzatek)
- tests: Fix NVMe tests on systems with empty DMI data (Tomas Bzatek)
- WIP: Remove workarounds for 3.0 API backwards compatibility (Vojtech Trefny)
- Fix LoopTech enum in Python overrides (Vojtech Trefny)
- Make changes to Python override enums backwards compatible (Vojtech Trefny)
- ci: Add GH actions job to run Blivet tests on PRs (Vojtech Trefny)
- lvm: Add 'shared' parameter to lvm_lvactivate (Vojtech Trefny)
- Add BlockDev.switch_init_checks to overrides only (Vojtech Trefny)
- doc: Document the API changes related to runtime dependency checks (Vojtech Trefny)
- tests: Do not create test device for tests that don't need them (Vojtech Trefny)
- Fix single member enums in Python overrides (Vojtech Trefny)
- Remove runtime dependency checks when loading plugins (Vojtech Trefny)
- fs/xfs: Open device read-only for xfs_info (Marius Vollmer)
- lvm: Add support for starting and stopping VG locking (Vojtech Trefny)
- Use our logging function instead of g_debug in boilerplate_generator (Vojtech Trefny)
- tests: Skip LVM resize tests on CentOS 9 Stream (Vojtech Trefny)
- tests: Make sure the "fake" PATH for tests exists (Vojtech Trefny)
- tests: XFS no longer needs to be mounted to get info (Vojtech Trefny)
- tests: Remove obsolete skip from BtrfsTestCreateDeleteSubvolume (Vojtech Trefny)
- lvm-dbus: Remove random debug messages from get_lv_data_from_props (Vojtech Trefny)
- fs: Don't require XFS filesystem to be mounted when getting info (Marius Vollmer)
- tests: Fix test for inactive LV resize (Vojtech Trefny)
- ci: Add custom version command for Packit (Vojtech Trefny)
- lvm: Remove multiple public LVM constants from lvm.h (Vojtech Trefny)
- ci: Add a GH actions job to build UDisks on PRs (Vojtech Trefny)
- spec: Remove dependency on dosfstools and xfsprogs from fs-devel (Vojtech Trefny)
- ci: Remove the custom GH action for RPM builds (Vojtech Trefny)
-  spec: Bump release to 195 for Packit daily builds (Vojtech Trefny)
- ci: Use Packit for daily builds in Copr (Vojtech Trefny)
- ci: Add Packit configuration for RPM builds on PRs (Vojtech Trefny)
- misc: Fix playbook for installing test dependencies (Vojtech Trefny)
- ci: Do not install test dependencies for csmock tests (Vojtech Trefny)
- Allow installing only build dependencies using the Ansible playbook (Vojtech Trefny)
- Allow resizing of inactive LVs with latest LVM (Vojtech Trefny)
- Include LVM cli in the LVM DBus plugin dependencies (Vojtech Trefny)
- tests: Skip lvm_dbus_tests.LvmTestLVcreateRemove on CentOS 8 (Vojtech Trefny)
- ci: Update chroots for RPM builds (Vojtech Trefny)
- fs: Improve the exFAT label checks (Alberto Garcia)
- misc: Add exfatprogs to test dependencies (Vojtech Trefny)
- Run external programs with the C.UTF-8 locale (Alberto Garcia)
- nvme: Return NULL in case the supported NVMe revision is not reported (Tomas Bzatek)
- nvme: Strip trailing whitespaces from subsysnqn when matching the device tree (Tomas Bzatek)
- Fix BlockDev.DMTech enum after removing DM RAID support (Vojtech Trefny)
- Revert "tests: Skip DDF RAID tests on rawhide" (Vojtech Trefny)
- Remove DMRAID support from the DM plugin (Vojtech Trefny)
- nvme: Fix zeroed struct fields detection (Tomas Bzatek)
- nvme: Use libnvme-1.2's nvme_uuid_to_string() (Tomas Bzatek)
- tests: Fix test case name for f2fs_test.F2FSMkfsWithFeatures (Vojtech Trefny)
- fs: Fix parsing F2FS info from dump.f2fs >= 1.15 output (Vojtech Trefny)
- tests: Remove obsolete skip for kbd_tests (Vojtech Trefny)
- tests: Skip DDF RAID tests on rawhide (Vojtech Trefny)
- btrfs: Fix parsing snapshot info without valid otime (Vojtech Trefny)
- crypto: Add support for opening FileVault encrypted devices (Vojtech Trefny)
- part: Add function to set partition UUID (Vojtech Trefny)
- nvme: Fix namespace identifiers (Tomas Bzatek)
- Drop skip_patterns from configure.ac and plugin_apis/Makefile.am (Vratislav Podzimek)
- Add BlockDev.crypto_luks_uuid to overrides only (Vojtech Trefny)
- crypto: Remove bd_crypto_luks_uuid function (Vojtech Trefny)
- Add BlockDev.loop_get_backing_file to overrides only (Vojtech Trefny)
- loop: Remove the bd_loop_get_backing_file function (Vojtech Trefny)
- loop: Add bd_loop_info function (Vojtech Trefny)
- crypto: Fix missing memory/lifetime annotations (Vojtech Trefny)
- tests: Loop tests cleanup (Vojtech Trefny)
- tests: Add tests for loop_setup part_probe option (Vojtech Trefny)
- tests: Use loop plugin to set up 4k devices for crypto test (Vojtech Trefny)
- loop: Allow setting sector size in loop_setup (Vojtech Trefny)
- configure: Add missing check for libuuid to the NVMe plugin (Vojtech Trefny)
- Update the comment in configure.ac to avoid numbers (Vratislav Podzimek)
- misc: Remove "warn: false" from Ansible "command" (Vojtech Trefny)
- Fix various typos and spelling errors (Vojtech Trefny)
- crypto: Fix double free in write_escrow_data_file (Vojtech Trefny)
- tests: Formatting fix (Vojtech Trefny)
- tests: Suppress output when creating cert in CryptoTestEscrow (Vojtech Trefny)
- crypto: Fix error path in bd_crypto_escrow_device (Vojtech Trefny)
- crypto: Fix GError overwrite from libvolume_key (Vojtech Trefny)
- spec: Change license string to the SPDX format required by Fedora (Vojtech Trefny)
- part: Add tests with 4k sector devices (Vojtech Trefny)
- crypto: Make the BD_CRYPTO_CHI_SQUARE constants private (Vojtech Trefny)
- crypto: Remove BD_CRYPTO_LUKS_METADATA_SIZE definition (Vojtech Trefny)
- fs: Do not allow running as different UID/GID for non-root (Vojtech Trefny)
- fs: Clarify the run_as_user option for bd_fs_mount/unmount (Vojtech Trefny)
- tests: Fix test_swapon_pagesize on systems with 64k pages (Vojtech Trefny)
- spec: Obsolte the kbd and kbd-devel subpackages (Vojtech Trefny)
- nvme_test: Use shutil.which instead of distutils.spawn.find_executable (Vojtech Trefny)
- Remove KBD plugin (Vojtech Trefny)
- crypto: Use crypt_keyfile_device_read for reading keyfiles (Vojtech Trefny)
- crypto: Bump required version of cryptsetup to 2.3.0 (Vojtech Trefny)
- ci: Remove LGTM config file (Vojtech Trefny)
- misc: Fix installing pylint on Ubuntu/Debian (Vojtech Trefny)
- ci: Add GH actions CodeQL static analysis workflow (Vojtech Trefny)
- blockdev: Mark errors in the library functions as optional (Vojtech Trefny)
- lvm: Add missing "optional" tags for errors in docstrings (Vojtech Trefny)
- part: Make error optional (Vojtech Trefny)
- part: Fix docstring for multiple bd_part_set_* functions (Vojtech Trefny)
- part: Fix a memory leak (Vojtech Trefny)
- part: Remove some libraries/includes we no longer need (Vojtech Trefny)
- part: Fix typos (Vojtech Trefny)
- part: Log the warning in close_context instead of using g_warning (Vojtech Trefny)
- part: Fix tech for bd_part_set_part_id (Vojtech Trefny)
- docs: Explain part plugin API changes in the documentation (Vojtech Trefny)
- part: Add a function to set GPT partition flags/attributes (Vojtech Trefny)
- part: Add a function to set bootable flag for MSDOS partitions (Vojtech Trefny)
- part: Add GPT partition attributes to BDPartSpec (Vojtech Trefny)
- part: Add partition type/ID to BDPartSpec (Vojtech Trefny)
- nvme: Rework the disconnect device topology crawl (Tomas Bzatek)
- fs: Memory leak fixes (Tomas Bzatek)
- part: Remove parted flags related code (Vojtech Trefny)
- nvme: Add BD_NVME_NS_FEAT_ROTATIONAL (Tomas Bzatek)
- nvme: Avoid sending NVME_IDENTIFY_CNS_NS_DESC_LIST on older devices (Tomas Bzatek)
- spec: Remove test dependencies comment (Vojtech Trefny)
- spec: Add some missing dependencies and versioned dependencies (Vojtech Trefny)
- fs: Log when we fail to remove temporary mount point directory (Vojtech Trefny)
- mpath: Fix potential NULL pointer dereference (Vojtech Trefny)
- nvme: Extend BDNVMELBAFormat with metadata_size (Tomas Bzatek)
- fs: Fix calling bd_fs_mkfs with empty label or UUID (Vojtech Trefny)
- utils: Introduce bd_extra_arg_list_free() (Tomas Bzatek)
- ci: Update Fedora versions for RPM build tests (Vojtech Trefny)
- mpath: Memory leak fix (Vojtech Trefny)
- lvm-dbus: Fix double free in bd_lvm_(write)cache_attach (Vojtech Trefny)
- fs: Fix nilfs2 dependencies (Tomas Bzatek)
- fs: Add a mkfs option to disable creating partition table (Vojtech Trefny)
- lvm-dbus: Fix various GError overwrites (Vojtech Trefny)
- docs: Add new functions to docs/libblockdev-sections.txt (Vojtech Trefny)
- fs: Fix macro name for bd_fs_mkfs_options_get_type (Vojtech Trefny)
- fs: Fix docstring and declarations for bd_fs_features (Vojtech Trefny)
- fs: Remove filesystem specific wipe function (Vojtech Trefny)
- fs: Add a "force" mkfs option for bd_fs_mkfs (Vojtech Trefny)
- tests: Try harder when unmounting devices in tests (Vojtech Trefny)
- fs: Do not call mkfs with --force (or similar) by default (Vojtech Trefny)
- tests: Temporarily skip bcache tests on rawhide (Vojtech Trefny)
- tests: Temporarily skip LvmTestPartialLVs on rawhide (Vojtech Trefny)
- lvm: Expose tree structure of LVs (Marius Vollmer)
- fs/ext: Use libext2fs instead of spawning dumpe2fs (Marius Vollmer)
- spec: Require the same version utils from plugins (Vojtech Trefny)
- fs: Add API for getting list of supported filesystems (Vojtech Trefny)
- fs: Remove the extra error prefix from bd_fs_clean() (Tomas Bzatek)
- fs: Add the dry run option for bd_fs_nilfs2_mkfs_options (Vojtech Trefny)
- fs: Fix nilfs2 mkfs util in BDFSInfo (Vojtech Trefny)
- tests: Add a test calling bd_fs_mkfs with a nonexisting filesystem (Vojtech Trefny)
- Fix calling bd_fs_mkfs without options from Python (Vojtech Trefny)
- fs: Add a generic function for checking UUID format (Vojtech Trefny)
- fs: Add a generic function for checking label format (Vojtech Trefny)
- tests: Use ext instead of xfs in MountTestCase.test_mount_ro_device (Vojtech Trefny)
- tests: Create bigger devices for XFS tests (Vojtech Trefny)
- tests: Fix names for FS features tests (Vojtech Trefny)
- fs: Add partition IDs/types to BDFSFeatures (Vojtech Trefny)
- tests: Create "nodev" test cases FS tests that don't need storage (Vojtech Trefny)
- lvm: Fix bd_lvm_get_supported_pe_sizes in Python on 32bit (Vojtech Trefny)
- md: Add container name to BDMDDetailData (Vojtech Trefny)
- Add a test case for DDF arrays/containers (Vojtech Trefny)
- mdraid: Try harder to get container UUID in bd_md_detail (Vojtech Trefny)
- lvm: Add description for the "missing" field in BDLVMPVdata (Vojtech Trefny)
- fs: Fix optional error handling in fs_mount helper function (Vojtech Trefny)
- fs: Allow specifying fstype for generic FS functions (Vojtech Trefny)
- fs: Fix BD_FS_LAST_FS after removing ReiserFS support (Vojtech Trefny)
- fs: Add API for querying filesystem "features" (Vojtech Trefny)
- tests: Skip nvme hostnqn tests on non-standard project prefixes (Tomas Bzatek)
- tests: Add nvme Host NQN manipulation tests (Tomas Bzatek)
- nvme: Minor doc strings fixes (Tomas Bzatek)
- nvme: Generate fallback Host NQN when /etc/nvme/hostnqn is not present (Tomas Bzatek)
- nvme: Add methods to retrieve and set Host NQN and Host ID (Tomas Bzatek)
- nvme: Differentiate fabrics connection error codes (Tomas Bzatek)
- nvme: Add helper to get string from BDNVMESelfTestResult (Tomas Bzatek)
- ci: Update the csmock GitHub actions configuration (Vojtech Trefny)
- ci: Run rpmbuild tests in GitHub actions (Vojtech Trefny)
- ci: Rename csmock.Dockerfile to ci.Dockerfile (Vojtech Trefny)
- misc: Add libnvme to list of packages to install on Fedora (Vojtech Trefny)
- ci: Run csmock static analysis on PRs using GitHub Actions (Vojtech Trefny)
- add new api testcases (root)
- Fix typos (Michael Biebl)
- Fix mismatched functions return value type (zhanghongtao)
- tests: Enhance nvme disconnect tests (Tomas Bzatek)
- nvme: Fix device path handling in bd_nvme_disconnect_by_path() (Tomas Bzatek)
- tests: Loosen nvme error log retrieval tests (Tomas Bzatek)
- nvme: Fix LBA Format data size matching in bd_nvme_format() (Tomas Bzatek)
- tests: Skip test_lvpartial on RHEL/CentOS 9 (Vojtech Trefny)
- lvm: Enhancements for LVM2 RAID support (Marius Vollmer)
- nvme: Fix leaking fd in bd_nvme_sanitize() (Tomas Bzatek)
- tests: Fix nvme tests for old kernels (Tomas Bzatek)
- tests: Skip LVM DBus writecache tests too (Vojtech Trefny)
- nvme: Clarify self-test operation log values (Tomas Bzatek)
- tests: Skip test_lvcreate_type on CentOS/RHEL 9 (Vojtech Trefny)
- nvme: Report temperature in Kelvins (Tomas Bzatek)
- tests: Fix checking hostnqn length in get_nvme_hostnqn (Vojtech Trefny)
- tests: Fix nvme namespace LBA Format enumeration (Tomas Bzatek)
- nvme: Fix namespace LBA formats calculation (Tomas Bzatek)
- nvme: Fix NSID assignment (Tomas Bzatek)
- tests: Add tests for bd_nvme_find_ctrls_for_ns() (Tomas Bzatek)
- nvme: Add bd_nvme_find_ctrls_for_ns() (Tomas Bzatek)
- tests: Simplify nvme loop target setup (Tomas Bzatek)
- crypto: Add label and subsystem to BDCryptoLUKSInfo (Vojtech Trefny)
- crypto: Add support for setting label and UUID for LUKS devices (Vojtech Trefny)
- tests: nvme-cli 2.x adaptations (Tomas Bzatek)
- tests: Use system host NQN for nvme tests (Tomas Bzatek)
- tests: Load the nvme-fabrics kernel module for nvme tests (Tomas Bzatek)
- part: Align end sector when resizing partition to max size (Vojtech Trefny)
- fs: Remove support for ReiserFS (Vojtech Trefny)
- misc: Add keyutils libs to the dependencies playbook (Vojtech Trefny)
- misc: Update distributions in Vagrantfile (Vojtech Trefny)
- tests: Skip LVM writecache tests on our 32bit machines (Vojtech Trefny)
- fs: Fix tech mode for bd_fs_mkfs (Vojtech Trefny)
- fs: Fix misspelled BDFSMkfsOptions in bd_fs_mkfs docstring (Vojtech Trefny)
- utils: Fix docstring for bd_utils_version_cmp (Vojtech Trefny)
- utils: Allow passing NULL to bd_extra_arg_free/copy (Vojtech Trefny)
- utils: Add description for fields in BDExtraArg (Vojtech Trefny)
- s390: Fix multiline comments that look like docstrings (Vojtech Trefny)
- Use nullable and optional GI annotations instead of allow-none (Vojtech Trefny)
- crypto: Fix parameters and docstring for bd_crypto_keyring_add_key (Vojtech Trefny)
- docs: Add missing functions to libblockdev-sections.txt (Vojtech Trefny)
- lvm-dbus: Allow passing NULL for error (Vojtech Trefny)
- lvm: Allow passing NULL for error (Vojtech Trefny)
- tests: Adapt error strings for libnvme-1.0-rc4 (Tomas Bzatek)
- nvme: Add support for TP8010 `hostsymname` fabrics option (Tomas Bzatek)
- tests: Use NILFS2 instead of NTFS to test mount helper execution (Vojtech Trefny)
- nvme: Introduce BD_NVME_ERROR_BUSY (Tomas Bzatek)
- nvme: Simplify error reporting (Tomas Bzatek)
- nvme: Fix error category for nvmf_get_discovery_log() codes (Tomas Bzatek)
- Remove __init__.py from out gi.overrides directory (Vojtech Trefny)
- tests: Fix multiple issues found by LGTM (Vojtech Trefny)
- boilerplate_generator: Remove unused variable assignment (Vojtech Trefny)
- crypto: Remove useless comparison in progress report in luks_format (Vojtech Trefny)
- lvm: Use correct integer type in for comparison (Vojtech Trefny)
- Add LGTM.com configuration (Vojtech Trefny)
- build: Include nvme.h in includes/ (Tomas Bzatek)
- tests: Add duplicate nvme fabrics connection tests (Tomas Bzatek)
- tests: Use libblockdev loop plugin for nvme backing devices (Tomas Bzatek)
- nvme: Fix errno string translation (Tomas Bzatek)
- nvme: Initialize libnvme logging (Tomas Bzatek)
- tests: Add nvme discover tests (Tomas Bzatek)
- nvme: Add discover functionality (Tomas Bzatek)
- nvme: Add ability to supply extra options to bd_nvme_connect() (Tomas Bzatek)
- tests: Add basic initiator tests (Tomas Bzatek)
- nvme: Add basic initiator support (Tomas Bzatek)
- tests: Extend nvme testbed with multiple namespaces (Tomas Bzatek)
- tests: Decouple NVMe target setup and the connection (Tomas Bzatek)
- Update skipping tests in skip.yml (Vojtech Trefny)
- nvme: Add more BDNVMEControllerInfo fields (Tomas Bzatek)
- install-test-dependencies: Do not install reiserfs-utils on Fedora (Vojtech Trefny)
- lvm-dbus: Add support for changing compression and deduplication (Vojtech Trefny)
- swap: Allow passing NULL for error (Vojtech Trefny)
- s390: Allow passing NULL for error (Vojtech Trefny)
- nvdimm: Allow passing NULL for error (Vojtech Trefny)
- mpath: Allow passing NULL for error (Vojtech Trefny)
- mdraid: Allow passing NULL for error (Vojtech Trefny)
- fs: Fix propagating error in bd_fs_mount/bd_fs_unmount (Vojtech Trefny)
- tests: Do not load the NVMe plugin in library and overrides tests (Vojtech Trefny)
- tests: Skip NVMe plugin tests on Debian and CentOS 9 (Vojtech Trefny)
- dist: Add nvme subpackage (Tomas Bzatek)
- tests: Add dummy sanitize tests (Tomas Bzatek)
- nvme: Add sanitize operation support (Tomas Bzatek)
- nvme: Add sanitize log page retrieval (Tomas Bzatek)
- tests: Add dummy nvme format tests (Tomas Bzatek)
- nvme: Add support for formatting namespaces (Tomas Bzatek)
- tests: Add nvme device self-test tests (Tomas Bzatek)
- nvme: Add support for device self-test (Tomas Bzatek)
- tests: Provide basic nvme plugin tests (Tomas Bzatek)
- tests: Add methods to set up a kernel NVMe target-based testing device (Tomas Bzatek)
- nvme: Introduce new 'nvme' plugin (Tomas Bzatek)
- kbd: Allow passing NULL for error (Vojtech Trefny)
- kbd: Add missing progress reporting to bd_kbd_zram_add_device (Vojtech Trefny)
- loop: Allow passing NULL for error (Vojtech Trefny)
- loop: Remove unused local GError (Vojtech Trefny)
- s390: Remove double fclose in bd_s390_dasd_online (#2045784) (Vojtech Trefny)
- dm: Allow passing NULL for error (Vojtech Trefny)
- crypto: Allow passing NULL for error (Vojtech Trefny)
- fs: Allow passing NULL for error (Vojtech Trefny)
- btrfs: Allow passing NULL for error (Vojtech Trefny)
- check_deps: Allow passing NULL for error (Vojtech Trefny)
- kbd: Fix leaking error in bd_kbd_bcache_detach (Vojtech Trefny)
- kbd: Fix potential NULL pointer dereference in bd_kbd_bcache_create (Vojtech Trefny)
- kbd: Add missing progress reporting to bd_kbd_bcache_create (Vojtech Trefny)
- crypto: Remove unused and leaking error in write_escrow_data_file (Vojtech Trefny)
- fs: Return BD_FS_ERROR_UNKNOWN_FS on mounting unknown filesystem (Tomas Bzatek)
- tests: Use losetup to create 4k sector size loop device for testing (Vojtech Trefny)
- tests: Make smaller images for test_lvcreate_type (Vojtech Trefny)
- tests: Wait for raid and mirrored LVs to be synced before removing (Vojtech Trefny)
- spec: Require the same version of utils for lvm-devel and lvm-dbus-devel (Vojtech Trefny)
- tests: Fix creating loop device for CryptoTestLuksSectorSize (Vojtech Trefny)
- lvm: Use "lvmconfig full" to get valid config instead of "current" (Vojtech Trefny)
- lvm: Allow using empty name for VDO pool when creating VDO volumes (Vojtech Trefny)
- vdo_stats: Default to 100 % savings for invalid savings values (Vojtech Trefny)
- lvm: Do not set global config to and empty string (Vojtech Trefny)
- tests: Fix resetting global LVM config after LVM devices file test (Vojtech Trefny)
- lvm: Do not include duplicate entries in bd_lvm_lvs output (Vojtech Trefny)
- tests: Fix skipping NVDIMM tests on rawhide (Vojtech Trefny)
- tests: Skip NVDIMM enable/disable and reconfigure tests on rawhide (Vojtech Trefny)
- lvm: Force enable LVM devices file for LvmTestDevicesFile (Vojtech Trefny)
- lvm: Report special error when system.devices file is not enabled (Vojtech Trefny)
- crypto: Do not use libcryptsetup flags directly in crypto.h (Vojtech Trefny)
- Create smaller test images for integrity tests (Vojtech Trefny)
- Add support for creating and activating integrity devices (Vojtech Trefny)
- tests: Remove test for NTFS read-only mounting (Vojtech Trefny)
- lvm: Fix reading statistics for VDO pools with VDO 8 (Vojtech Trefny)
- tests: Fix copy-paste in CryptoTestTrueCrypt and CryptoTestBitlk (Vojtech Trefny)
- tests: Use BlockDev.utils_get_linux_version instead of os.uname (Vojtech Trefny)
- tests: Use packaging.version instead of distutils.version (Vojtech Trefny)
- tests: Use shutil.which instead of distutils.spawn.find_executable (Vojtech Trefny)
- Do not use distutils to get Python library path (Vojtech Trefny)
- overrides: Fix translating exceptions in ErrorProxy (Vojtech Trefny)
- lvm: Add functions for managing LVM devices file (Vojtech Trefny)
- lvm: Allow configuring global "device filter" for LVM commands (Vojtech Trefny)
- README: Add information about 3.0 and branches (Vojtech Trefny)
- docs: Fix opening and ending tag mismatch in 3.0-api-changes.xml (Vojtech Trefny)
- configure.ac: Remove invalid email address for bug reports (Vojtech Trefny)
- Add new argument for bd_fs_wipe/clean to control force wipe (Vojtech Trefny)
- tests: Refactor XFS resize tests (Vojtech Trefny)
- tests: Fix checking for XFS shrink support in tests (Vojtech Trefny)
- crypto: Fix checking if crypt_token_max exists (Vojtech Trefny)
- exec: Fix macro arguments (Manuel Wassermann)
- exec: Fix deprecated glib function call Glib will rename "g_spawn_check_exit_status()" to "g_spawn_check_wait_status()" in version 2.69. (Manuel Wassermann)
- crypto: Let cryptsetup autodect encryption sector size when not specified (Vojtech Trefny)
- tests: Do not check that XFS shrink fails with xfsprogs >= 5.12 (Vojtech Trefny)
- tests: Make sure the test temp mount is always unmounted (Vojtech Trefny)
- lvm-dbus: Report error when function returns no object and no job (Vojtech Trefny)
- tests: Temporarily skip test_snapshotcreate_lvorigin_snapshotmerge (Vojtech Trefny)
- tests: Temporarily skip test_snapshotcreate_lvorigin_snapshotmerge (Vojtech Trefny)
- Fix skipping tests on Debian testing (Vojtech Trefny)
- kbd: Fix memory leak (Vojtech Trefny)
- fs: Use "-n" for label in bd_fs_exfat_mkfs_options (Vojtech Trefny)
- fs: Fix NULL <--> FALSE return values (Tomas Bzatek)
- vfat: Convert labels uppercase (Tomas Bzatek)
- vfat: Add check for invalid characters in bd_fs_vfat_check_label() (Tomas Bzatek)
- tests: Tag LvmPVVGLVcachePoolCreateRemoveTestCase as unstable (Vojtech Trefny)
- tests: Force remove LVM VG /dev/ entry not removed by vgremove (Vojtech Trefny)
- tests: Do not try to remove VG before removing the VDO pool (Vojtech Trefny)
- part: Fix elements leak in bd_part_get_part_by_pos() (Tomas Bzatek)
- Add missing plugins to the default config (Vojtech Trefny)
- crypto: Fix default key size for non XTS ciphers (Vojtech Trefny)
- fs: Allow using empty label for vfat with newest dosfstools (Vojtech Trefny)
- tests: Call fs_vfat_mkfs with "--mbr=n" extra option in tests (Vojtech Trefny)
- crypto: Allow running info functions on both block and mapped device (Vojtech Trefny)
- build: Remove stray comma (Tomas Bzatek)
- remove unused variable and fix build with LLVM/clang (Tomasz Paweł Gajc)
- nvdimm: Remove deprecated function bd_nvdimm_namepace_get_supported_sector_sizes (Vojtech Trefny)
- lvm: Remove deprecated constant BD_LVM_MAX_LV_SIZE (Vojtech Trefny)
- exec: Use our logging instead of g_warning in _utils_exec_and_report_progress (Vojtech Trefny)
- utils: Allow passing NULL for error (Vojtech Trefny)
- tests: Do not use Python "six" module (Vojtech Trefny)
- Remove Python 2 support (Vojtech Trefny)
- crypto: Allow unlocking LUKS devices using key in the kernel keyring (Vojtech Trefny)
- crypto: Add a function to add a key to the kernel keyring (Vojtech Trefny)
- crypto: Add function to get information about LUKS2 tokens (Vojtech Trefny)
- fs: Add support for UDF filesystem (Vojtech Trefny)
- misc: Add ansible playbook to install test dependencies (Vojtech Trefny)
- tests: Include btrfs_test in tests/fs_tests/__init__.py (Vojtech Trefny)
- Fix max size limit for LVM thinpool metadata (Vojtech Trefny)
- tests: Adjust size of test devices used in fs_tests.generic_test (Vojtech Trefny)
- fs: Add Btrfs to the filesystem plugin (Vojtech Trefny)
- tests: Fix skipping fs tests after the test split (Vojtech Trefny)
- lvm: Use the UNUSED macro instead of __attribute__((unused)) (Vojtech Trefny)
- lvm: Do not use thin_metadata_size to recommend thin metadata size (Vojtech Trefny)
- lvm: Set thin metadata limits to match limits LVM uses in lvcreate (Vojtech Trefny)
- tests: Use set when gathering tests in run_test to avoid duplicates (Vojtech Trefny)
- fs: Add BD_FS_TECH_MODE_SET_UUID to fs.api (Vojtech Trefny)
- tests: Add tests for bd_fs_is_tech_avail for each filesystem (Vojtech Trefny)
- tests: Add missing NTFS test cases (Vojtech Trefny)
- tests: Move filesystem tests into separate directory (Vojtech Trefny)
- tests: Move fake utils and test configs to separate directories (Vojtech Trefny)
- fs: Wipe all signatures when running wipe with wipe_all set to TRUE (Vojtech Trefny)
- BlockDev.py: Add Python overrides for bd_fs_exfat_* functions (Vojtech Trefny)
- tests: Add test cases for nilfs2 (Vojtech Trefny)
- BlockDev.py: Add Python override for fs_nilfs2_mkfs (Vojtech Trefny)
- fs: Add generic mkfs function with extra options (Vojtech Trefny)
- lvm: Fix bd_lvm_vdopooldata_* symbols (Tomas Bzatek)
- fs: Fix resize flags for nilfs (Vojtech Trefny)
- fs: Do not report error when errors were fixed by e2fsck (Vojtech Trefny)
- loop: Retry LOOP_SET_STATUS64 on EAGAIN (Vojtech Trefny)
- fs: Add function to validate exFAT label (Vojtech Trefny)
- fs: Fix bd_fs_can_get_free_space with exFAT (Vojtech Trefny)
- fs: Fix DEPS_LAST for exFAT (Vojtech Trefny)
- tests: Remove debug print from FSTestCase.setUpClass (Vojtech Trefny)
- f2fs: Fix a typo in error message (Tomas Bzatek)
- tests: Add exec input tests (Tomas Bzatek)
- tests: Add null-byte exec tests (Tomas Bzatek)
- tests: Add bufferbloat exec tests (Tomas Bzatek)
- exec: Clarify the BDUtilsProgExtract callback documentation (Tomas Bzatek)
- exec: Use non-blocking read and process the buffer manually (Tomas Bzatek)
- fs: Add support for exFAT filesystem (Vojtech Trefny)
- tests: Remove MDTestNominateDenominateActive test case (Vojtech Trefny)
- misc: Update Vagrantfile (Vojtech Trefny)
- tests: Remove some old/obsolete rules to skip tests (Vojtech Trefny)
- tests: Mark f2fs resize test as unstable (Vojtech Trefny)
- tests: Fix f2fs shrink test (Vojtech Trefny)
- Add separate tool for VFAT filesystem resize and use it in the FS plugin (Vojtech Trefny)
- vdo: Remove standalone VDO plugin (Vojtech Trefny)
- tests: Adjust sizes in generic FS resize test for VFAT resize (Vojtech Trefny)
- fs: Fix bd_fs_can_get_free_space name in declaration (Vojtech Trefny)
- exec: Fix polling for stdout and stderr (Tomas Bzatek)
- mdraid: Fix use after free (Vojtech Trefny)
- module: Fix memory leak in libkmod logging function redirect (Vojtech Trefny)
- logging: Fix potential memory leak when logging function fails (Vojtech Trefny)
- swap: Fix memory leak (Vojtech Trefny)
- mdraid: Fix memory leak (Vojtech Trefny)
- mdraid: Fix copy-paste error when checking return value (Vojtech Trefny)
- lvm-dbus: Fix memory leak (Vojtech Trefny)
- kbd: Fix memory leak (Vojtech Trefny)
- fs: Fix memory leak (Vojtech Trefny)
- fs: Fix typo (Vojtech Trefny)
- dm: Fix memory leak in the DM plugin and DM logging redirect function (Vojtech Trefny)
- crypto: Fix memory leak (Vojtech Trefny)
- part: Fix expected partition size after resize with older libfdisk (Vojtech Trefny)
- part: When resizing allow growing up to 4 MiB above max size (Vojtech Trefny)
- part: Fix return value of get_max_part_size for ungrowable parts (Vojtech Trefny)
- spec: Remove gdisk dependency (Vojtech Trefny)
- tests: Fix getting list of NVDIMM devices for tests (Vojtech Trefny)
- part: Remove libparted information from the plugin docstring (Vojtech Trefny)
- part: Fix few typos in comments and docstrings (Vojtech Trefny)
- Re-read entire partition table after adding extended partition (Vojtech Trefny)
- part: Take exclusive lock instead of shared before writing changes (Vojtech Trefny)
- Remove remaining parted functions from the part plugin (Vojtech Trefny)
- Use libfdisk for partition resizing (Vojtech Trefny)
- Call 'fdisk_reread_changes' after adding/removing partitions (Vojtech Trefny)
- Use libfdisk to create new partitions (Vojtech Trefny)
- Redirect libfdisk log messages to our log (Vojtech Trefny)
- Manually add metadata partitions to the list of partitions (Vojtech Trefny)
- Do not remove all "flags" in bd_part_set_part_flags on GPT (Vojtech Trefny)
- Use libfdisk to get partition by its position (Vojtech Trefny)
- Use libfdisk to get disk partitions and free regions (Vojtech Trefny)
- Do not overwrite errors from 'get_part_num' (Vojtech Trefny)
- Use libfdisk to get partition spec (Vojtech Trefny)
- Use libfdisk to set parted "flags" in bd_part_set_flags (Vojtech Trefny)
- Use libfdisk to set parted "flags" in bd_part_set_flag (Vojtech Trefny)
- mdraid: Try harder to get container UUID in bd_md_examine (Vojtech Trefny)
- mdraid: Do not ignore errors from bd_md_canonicalize_uuid in bd_md_examine (Vojtech Trefny)
- tests: Skip NTFS mount test on Debian testing (Vojtech Trefny)
- tests: Add missing method _get_lvm_version to LVM DBus tests (Vojtech Trefny)
- dm: Fix comparing DM RAID member devices UUID (Vojtech Trefny)
- Implement 'bd_part_get_type_str' without libparted (Vojtech Trefny)
- Use libfdisk to get partition ID instead of sfdisk (Vojtech Trefny)
- Add a static function to get partition number from name (Vojtech Trefny)
- Use libfdisk to set partition type/id instead of sfdisk/sgdisk (Vojtech Trefny)
- Use libfdisk to get GPT partition flags and GUID (Vojtech Trefny)
- Use libfdisk to set GPT "flags" instead of sgdisk (Vojtech Trefny)
- Rewrite 'bd_part_set_part_name' using libfdisk (Vojtech Trefny)
- Rewrite 'bd_part_get_disk_spec' and 'bd_part_set_disk_flag' to libfdisk (Vojtech Trefny)
- Implement create_table() and delete_part() using libfdisk (Vratislav Podzimek)
- configure: Fix libuuid requirement for FS plugin (Vojtech Trefny)
- fs: Fix return values in bd_fs_xfs_get_info (Vojtech Trefny)
- fs: Fix return values in bd_fs_reiserfs_get_info (Vojtech Trefny)
- fs: Fix two memory leaks in bd_fs_reiserfs_get_info (Vojtech Trefny)
- fs: Fix return values in bd_fs_ntfs_get_info (Vojtech Trefny)
- tests: Add tests for NILFS2 (Vojtech Trefny)
- tests: Do not use nilfs2 as "unsupported filesystem" in tests (Vojtech Trefny)
- tests: Adjust sizes for VFAT resize test (Vojtech Trefny)
- tests: Increase size of the test loop devices to 150 MiB (Vojtech Trefny)
- fs: Add support for NILFS2 filesystem (Vojtech Trefny)
- fs: Add functions to check filesystem UUID validity (Vojtech Trefny)
- fs: Add functions to check filesystem label validity (Vojtech Trefny)
- fs: Add label and UUID to BDFSNtfsInfo (Vojtech Trefny)
- fs: Ignore return code 1 during VFAT repair (Vojtech Trefny)
- tests: Fix calling super() in LVM tests with Python 2 (Vojtech Trefny)
- tests: Properly set log level for LVM tests parsing log entries (Vojtech Trefny)
- Add support for checking DBus API version in check_dbus_deps (Vojtech Trefny)
- lvm: Fix memory leak bd_lvm_cache_create_cached_lv (Vojtech Trefny)
- lvm-dbus: Fix memory leak in bd_lvm_cache_attach (Vojtech Trefny)
- lvm: Fix checking for LVM VDO dependencies (Vojtech Trefny)
- lvm: Add support for creating LVM writecache devices (Vojtech Trefny)
- Add blank line between stats of individual LVs in lvm-cache-stats (Vratislav Podzimek)
- exec: Fix setting locale for util calls (Vojtech Trefny)
- module.c: Fix error message when loading module without options (Vojtech Trefny)
- crypto: Fix few typos in comments and docstrings (Vojtech Trefny)
- Fix multiple typos in docstrings and comments (Vojtech Trefny)
- Fix multiple missing or wrong dosctrings (Vojtech Trefny)
- Move internal unprefixed constants from header files to source (Vojtech Trefny)
- docs: Remove non-existing functions from libblockdev-sections.txt (Vojtech Trefny)
- docs: Add missing functions to libblockdev-sections.txt (Vojtech Trefny)
- docs: Ignore internal header files during gtkdoc-scan (Vojtech Trefny)
- crypto: Fix docstring for bd_crypto_integrity_info_copy (Vojtech Trefny)
- Add link to the Python bindings documentation to docs main page (Vojtech Trefny)
- Add Dockerfile and howto for building Python bindigs documentation (Vojtech Trefny)
- utils: Convert log_task_status and get_next_task_id to "public" (Vojtech Trefny)
- fs: Mark bd_fs_f2fs_is_tech_avail as hidden (Vojtech Trefny)
- fs: Mark fs_info as static (Vojtech Trefny)
- docs: Add list of changed and removed functions in 3.0 to docs (Vojtech Trefny)
- lvm: Remove bd_lvm_data_lv_name and bd_lvm_metadadata_lv_name (Vojtech Trefny)
- lvm: Add functions for adding and deleting LV/VG/PV tags (Vojtech Trefny)
- lvm: Add missing attribute to bd_lvm_pvdata_copy in LVM DBUs plugin (Vojtech Trefny)
- lvm: Add LV/VG/PV tags lv/pv/vginfo functions (Vojtech Trefny)
- mdraid: Do not try to activate already active MDRAID devices (Vojtech Trefny)
- dm: Do not try to activate already active DMRAID sets (Vojtech Trefny)
- Bump version to be always ahead of 2.x-branch (Vojtech Trefny)
- Fix typo in bd_nvdimm_namepace_get_supported_sector_sizes (Vojtech Trefny)
- Mark VDO plugin as deprecated since 2.24 (Vojtech Trefny)
- Fix multiple uninitialized values discovered by coverity (Vojtech Trefny)
- fs: Fix potential NULL pointer dereference in mount.c (Vojtech Trefny)
- utils: Remove deadcode in exec.c (Vojtech Trefny)
- Do not check VDO saving percent value in LVM DBus tests (Vojtech Trefny)
- configure.ac: Avoid more bashisms (Matt Whitlock)
- mount: Fix a memleak (Tomas Bzatek)
- exec: Fix a memleak (Tomas Bzatek)
- vdo: Fix a memleak (Tomas Bzatek)
- configure.ac: Avoid bashisms (Lars Wendler)
- lvm: Fix getting cache stats for cache thinpools (Vojtech Trefny)
- tests: Specify loader for yaml.load in VDO tests (Vojtech Trefny)
- tests: Skip test_ntfs_get_free_space when mkntfs is not available (Vojtech Trefny)
- lvm-dbus: Fix memory leak in bd_lvm_thlvpoolname (Vojtech Trefny)
- lvm: Add a function to get VDO pool name for a VDO LV (Vojtech Trefny)
- lvm-dbus: Get data LV name for LVM VDO pools too (Vojtech Trefny)
- lvm-dbus: Add LVM VDO pools to bd_lvm_lvs (Vojtech Trefny)
- Do not skip LVM VDO tests when the kvdo module is already loaded (Vojtech Trefny)
- tests: Skip LVM VDO tests if kvdo module cannot be loaded (Vojtech Trefny)
- fs: Add convenience function to get free space on a filesystem (Vojtech Trefny)
- lvm-dbus: Do not activate LVs during pvscan --cache (Vojtech Trefny)
- fs: Add reiserfs and f2fs checks to bd_fs_check_deps (Vojtech Trefny)
- fs: Explicitly list modes in filesystems deps checks (Vojtech Trefny)
- fs: Return error when checking for vfat and f2fs UUID support (Vojtech Trefny)
- Allow small differences when checking for FAT size after a resize (Vojtech Trefny)
- vdo: Run "vdo create" with "--force" (Vojtech Trefny)
- Makefile: Allow passing arguments to run_tests.py from ci target (Vojtech Trefny)
- exec: Disable encoding when reading data from stdout/stderr (Vojtech Trefny)
- tests: Allow specifying tags when running tests (Vojtech Trefny)
- tests: Set gi.overrides.__path__ in run_tests script (Vojtech Trefny)
- tests: Remove skips for unsupported distributions (Vojtech Trefny)
- fs: Add support for ReiserFS filesystem (Vojtech Trefny)
- Add a function to exec process with given input (Vojtech Trefny)
- tests: Add option to run pdb for failed tests (Vojtech Trefny)
- fs_test: Fix generic resize for f2fs (Vojtech Trefny)
- fs_test: Fix checking for f2fs tools version for resizing (Vojtech Trefny)
- fs: Fix bd_fs_is_tech_avail with F2FS tech (Vojtech Trefny)
- Fix typo in (un)mount error messages (Vojtech Trefny)
- Fix docstring for "bd_fs_set_label" (Vojtech Trefny)
- Add functions to set UUID for filesystems (Vojtech Trefny)
- Make more room for the CI status (Vratislav Podzimek)
- utils: Add functions to get and check current linux kernel version (Tomas Bzatek)
- ext: Return empty string instead of "<none>" for empty UUID (Vojtech Trefny)
- Use all CPUs avaiable on host for the Vagrant VMs (Vratislav Podzimek)
- Add support for JSON output from lvm-cache-stats (Vratislav Podzimek)
- Do not open devices as read-write for read-only fs operations (Vojtech Trefny)
- Fix copy-paste bug in lvm.api (Vojtech Trefny)
- Add functions to get VDO stats for LVM VDO volumes (Vojtech Trefny)
- Move VDO statistics code to a separate file (Vojtech Trefny)
- Add support for BitLocker encrypted devices using cryptsetup (Vojtech Trefny)
- Add a helper function for closing an active crypto device (Vojtech Trefny)
- Manually remove symlinks not removed by udev in tests (Vojtech Trefny)
- Use libblkid to get label and UUID for XFS filesystems (Vojtech Trefny)
- Fix memory leak in LVM DBus plugin (Vojtech Trefny)
- Add function to get LVM VDO write policy from a string (Vojtech Trefny)
- Add extra parameters for creating LVM VDO volumes (Vojtech Trefny)
- Allow calling LVM functions without locking global_config_lock (Vojtech Trefny)
- Fix unknown index state enum value for LVM VDO (Vojtech Trefny)
- Fix LVM plugin so names in tests (Vojtech Trefny)
- Fix getting VDO data in the LVM DBus plugin (Vojtech Trefny)
- Fix getting string representation of unknown VDO state index (Vojtech Trefny)
- Add write policy and index size to LVM VDO data (Vojtech Trefny)
- Fix converting to VDO pool without name for the VDO LV (Vojtech Trefny)
- Fix tech category for 'bd_lvm_vdo_pool_convert' in the docstring (Vojtech Trefny)
- Add some helper functions to get LVM VDO mode and state strings (Vojtech Trefny)
- Add support for creating and managing VDO LVs with LVM (Vojtech Trefny)
- Do not hardcode pylint executable name in Makefile (Vojtech Trefny)
- Add a function to check if a tool supports given feature (Vojtech Trefny)
- fs: Fix checking for UID/GID == 0 (Vojtech Trefny)
- Fix expected cache pool name with newest LVM (Vojtech Trefny)
- fix build on shells where test == fails (Tim Biermann)
- Add a generic function to get size of a filesystem (Vojtech Trefny)
- Add repr and str function to our structs in Python (Vojtech Trefny)
- Add misc/.vagrant to .gitignore (Vratislav Podzimek)
- Update the misc/Vagrantfile to default to Fedora 30 (Vratislav Podzimek)
- Use alias for 'make' instead of MAKEFLAGS in vagrant VMs (Vratislav Podzimek)
- Install nss-tools and lvm2-dbusd on vagrant test VMs (Vratislav Podzimek)
- Use the current folder for sources in vagrant boxes (Vratislav Podzimek)
- Rename Vagrantfile.tmpl to Vagrantfile (Vratislav Podzimek)
- Fixed a number of memory leaks in lvm-dbus plugin (Matt Thompson)
- Skip f2fs tests if mkfs.f2fs is not available (Vojtech Trefny)
- Add function to set default level for logging (Vojtech Trefny)
- Add helper function for logging to stdout and make it default (Vojtech Trefny)
- Fix linking against utils on Debian (Vojtech Trefny)
- Use our logging function instead of g_warning (Vojtech Trefny)
- Redirect libdevmapper log to libblockdev log (Vojtech Trefny)
- Define custom log levels (Vojtech Trefny)
- Move logging functionality to a separate file (Vojtech Trefny)
- exec.c: Fix reading outputs with null bytes (Vojtech Trefny)
- Add F2FS filesystem support (Vojtech Trefny)
- Create a common function to get label and uuid of a filesystem (Vojtech Trefny)
- Mark all GIR file constants as guint64 (Vojtech Trefny)
- Redirect libkmod log to libblockdev log (Vojtech Trefny)
- lvm: Add exported information to BDLVMVGdata (Vojtech Trefny)
- Sync spec with downstream (Vojtech Trefny)

* Fri Jun 23 2023 Vojtech Trefny <vtrefny@redhat.com> - 3.0-1
- Libblockdev 3.0 release
